TestPanicResult

Enum TestPanicResult 

pub enum TestPanicResult<R> {
    Cool(R),
    Panic(Box<dyn Any + Send>),
}
Result of test_panic function.

Variants



Cool(R)

No panic result. Contains callback function result.



Panic(Box<dyn Any + Send>)

Panic result. Contains panic payload.

Implementations

Source

impl<R> TestPanicResult<R>

pub fn is_cool(&self) -> bool

Returns true if self is Cool.

pub fn is_panic(&self) -> bool

Returns true if self is Panic.

pub fn cool(self) -> Option<R>

Converts self into success result if any.

pub fn panic(self) -> Option<Box<dyn Any + Send>>

Converts self into panic payload if any.

pub fn value(&self) -> &R

Returns result value.

Panics

Panics if self is Panic.

pub fn payload(&self) -> &Box<dyn Any + Send>

Returns panic payload.

Panics

Panics if self is Cool.

pub fn message(&self) -> String

Returns panic message.

Panics

Panics if self is Cool or panic payload is not &str or String.

pub fn get_message(&self) -> Option<String>

Returns panic message if exists.

pub fn eq_almost(&self, other: &Self) -> bool
where R: PartialEq,

Tests self and other values to be almost equal.

This method ignores error message, only if other has no message. This is useful for toggling verification based on whether the message is known or not.

pub fn eq_nearly(&self, other: &Self) -> bool
where R: PartialEq,

Tests self and other values to be nearly equal.

This method ignores error message. This is useful when comparing two functions with similar behavior, but where only the error messages differ.